"""statograph: a Statuspage.io metrics duplication machine & utility.

https://upload.wikimedia.org/wikipedia/commons/f/fb/Pantograph_animation.gif"""

__author__ = "Chris Danis"
__version__ = "0.1.0"
__license__ = "GNU GPL v3.0"
__repository__ = "https://gerrit.wikimedia.org/r/plugins/gitiles/operations/software/statograph"
__copyright__ = """
Copyright © 2021 Chris Danis & the Wikimedia Foundation

This program is free software: you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation,
either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import time

from dataclasses import dataclass
from typing import MutableMapping, Optional


@dataclass
class Datapoint:
    """A timeseries datapoint: a numeric value with an associated timestamp.

    Timestamp is always UNIX epoch seconds.  Value is an arbitrary float.
    """
    timestamp: int  # UNIX epoch seconds
    value: float

    def __post_init__(self):
        """Rounds number to conform to (undocumented) API precision limit."""
        self.value = round(self.value, 9)


def pretty_timestamp(t: Optional[float]) -> str:
    """Given UNIX epoch seconds, pretty-prints it: Thu, 24 Jun 2021 21:35:00 +0000"""
    if t:
        return time.strftime('%a, %d %b %Y %H:%M:%S %z', time.gmtime(t))
    return 'None'


def set_user_agent(x: MutableMapping[str, str]) -> None:
    """Sets a reasonable User-Agent. x should be a requests headers-like object."""
    x['User-Agent'] = f"statograph/{__version__} ({__repository__}) {x['User-Agent']}"
