import unittest

from statograph.statuspage import Metric
from statograph.uploader import MetricUploader


class TestMetricUploader(unittest.TestCase):
    def test_time_bounds_small_update(self):
        # A metric last updated 10 minutes ago.
        # We should upload the past 10 minutes.
        m = Metric('xyzzy', 'some metric', 86400*30)
        mu = MetricUploader(m, now=lambda: 86400*30+60*10)
        start = mu.start_timestamp()
        end = mu.end_timestamp()
        self.assertEqual(start, 86400*30)
        self.assertEqual(end, 86400*30+60*10)

    def test_time_bounds_max_backlog(self):
        # A metric last updated two days past the epoch, when right now it is the 29th day
        # past the epoch.
        # We should upload a full batch of data starting at 2 days past the epoch.
        m = Metric('xyzzy', 'some metric', 86400*2)
        mu = MetricUploader(m, now=lambda: 86400*29)
        start = mu.start_timestamp()
        end = mu.end_timestamp()
        self.assertEqual(start, 86400*2)
        self.assertEqual(end, 86400*2 + mu.MAX_POINTS_PER_REQUEST * mu.STEP_SECONDS)

    def test_time_bounds_empty_metric(self):
        # A pristine metric with zero data present.
        # We should upload as much as possible.
        m = Metric('xyzzy', 'empty metric', None)
        mu = MetricUploader(m, now=lambda: 28*86400)
        start = mu.start_timestamp()
        end = mu.end_timestamp()
        # Can't be more than 28 days in the past...
        self.assertGreater(start, 0)
        # ...but should include part of the 28th day.
        self.assertLess(start, 86400)
        self.assertEqual(end, start + mu.MAX_POINTS_PER_REQUEST * mu.STEP_SECONDS)
